@@ -143,7 +143,10 @@ class CalcCoordinate():
             # determine number of leading zeros
             #lz = len(text) - len(str(int(text)))
             text = self.safe_eval(text)
-            text = "%03d" % int(text)
+            try:
+                text = "%03d" % int(text)
+            except Exception, e:
+                text = '?'
         return text
 
     def safe_eval(self, text):
@@ -151,7 +154,7 @@ class CalcCoordinate():
             tmp = eval(text,{"__builtins__":None},{})
         except (SyntaxError, Exception):
             self.warnings.append(self.WARNING_SYNTAX)
-            return 'X'
+            return '?'
         if round(tmp) != round(tmp, 1):
             self.warnings.append(self.WARNING_FLOAT % text)
         tmp = int(tmp)
@@ -170,7 +173,7 @@ class CalcCoordinate():
         text = text.replace(unichr(160), ' ')
         text = re.sub(ur''' +''', ' ', text)
         print text
-        matches = re.findall(ur'''(?<![a-zA-Z])([NS+-ns])\s?([A-Z() -+*/0-9]+?)[\s|]{1,2}([A-Za-z ()+*/0-9-]+)[.,\s]([A-Za-z ()+*/0-9-]+)['`\s,/]+([EOW+-eow])\s?([A-Za-z() +*/0-9-]+?)[\s|]{1,2}([A-Za-z ()+*/0-9-]+)[.,\s]([A-Za-z ()+*/0-9-]+)[\s'`]*(?![a-zA-Z])''', text)
+        matches = re.findall(ur'''(?<![a-zA-Z])([NSns])\s?([A-Z() -+*/0-9]+?)[\s|]{1,2}([A-Za-z ()+*/0-9-]+)[.,\s]([A-Za-z ()+*/0-9-]+)['`\s,/]+([EOWeow])\s?([A-Za-z() +*/0-9-]+?)[\s|]{1,2}([A-Za-z ()+*/0-9-]+)[.,\s]([A-Za-z ()+*/0-9-]+)[\s'`]*(?![a-zA-Z])''', text)
         found = []
         requires = set()
         for match in matches:
