@@ -590,14 +590,14 @@ class CacheDownloader(gobject.GObject):
         self.images = {}
         coordinate = coordinate.clone()
         self.current_cache = coordinate
-        #try:
-        print "* Downloading %s..." % (coordinate.name)
-        response = self.__get_cache_page(coordinate.name)
-        u = self.__parse_cache_page(response, coordinate)
-        #except Exception, e:
-        #    CacheDownloader.lock.release()
-        #    self.emit('download-error', e)
-        #    return self.current_cache
+        try:
+            print "* Downloading %s..." % (coordinate.name)
+            response = self.__get_cache_page(coordinate.name)
+            u = self.__parse_cache_page(response, coordinate)
+        except Exception, e:
+            CacheDownloader.lock.release()
+            self.emit('download-error', e)
+            return self.current_cache
         CacheDownloader.lock.release()
         self.emit('finished-single', u)
         return u
