@@ -390,8 +390,8 @@ class SimpleGui(object):
         return [p_x, p_y]
                 
         
-                
-    def _decode_htmlentities(self, string):
+    @staticmethod            
+    def _decode_htmlentities(string):
         def substitute_entity(match):
             from htmlentitydefs import name2codepoint as n2cp
             ent = match.group(3)
@@ -539,7 +539,7 @@ class SimpleGui(object):
 
             self.xgc_arrow.line_style = gtk.gdk.LINE_ON_OFF_DASH 
             ecc = int(error_circle_size * circle_size)
-            err = max(self.gps_data.error_bearing, 181) # don't draw multiple circles :-)
+            err = min(self.gps_data.error_bearing, 181) # don't draw multiple circles :-)
             err_start = (90-(display_bearing + err))*64
             err_delta = err * 2 * 64
             self.pixmap_arrow.draw_arc(self.xgc_arrow, False, center_x - ecc, center_y - ecc, ecc * 2, ecc * 2, err_start, err_delta)
@@ -716,9 +716,17 @@ class SimpleGui(object):
             else:
                 color = self.COLOR_DEFAULT
 
-            p = self._coord2point(c)
             xgc.set_rgb_fg_color(color)
 
+            p = self._coord2point(c)
+
+            if c.alter_lat != None and (c.alter_lat != 0 and c.alter_lon != 0):
+                print c.alter_lat
+                x = self._coord2point(geo.Coordinate(c.alter_lat, c.alter_lon))
+                if x != p:
+                    self.pixmap_marks.draw_line(xgc, p[0], p[1], x[0], x[1])
+
+
             if draw_short:
                 radius = radius / 2.0
 
@@ -1413,8 +1421,9 @@ class SimpleGui(object):
                 
     def refresh(self):
         self.drawing_area.queue_draw()
-                        
-    def replace_image_tag(self, m):
+                       
+    @staticmethod 
+    def replace_image_tag(m):
         if m.group(1) != None and m.group(1).strip() != '':
             return ' [Image: %s] ' % m.group(1).strip()
         else:
@@ -1641,13 +1650,13 @@ class SimpleGui(object):
         c.name = 'manual'
         return c
 
-        
-    def _strip_html(self, text):
+    @staticmethod 
+    def _strip_html(text):
         text = text.replace("\n", " ")
-        text = re.sub(r"""(?i)<img[^>]+alt=["']?([^'"> ]+)[^>]+>""", self.replace_image_tag, text)
+        text = re.sub(r"""(?i)<img[^>]+alt=["']?([^'"> ]+)[^>]+>""", SimpleGui.replace_image_tag, text)
         text = re.sub(r'(?i)<(br|p)[^>]*?>', "\n", text)
         text = re.sub(r'<[^>]*?>', '', text)
-        text = self._decode_htmlentities(text)
+        text = SimpleGui._decode_htmlentities(text)
         text = re.sub(r'[\n\r]+\s*[\n\r]+', '\n', text)
         return text.strip()
                 
